@@ -17,14 +17,6 @@ impl LessCodeEncryption {
         SMX::sm2_gen_keypair()
     }
     #[staticmethod]
-    fn sm2_sign(sk: String, data: String) -> String {
-        SMX::sm2_sign(sk, data)
-    }
-    #[staticmethod]
-    fn sm2_verify(sign: String, pk: String, data: String) -> bool {
-        SMX::sm2_verify(sign, pk, data)
-    }
-    #[staticmethod]
     fn sm2_encrypt(pk: String, data: String) -> String {
         SMX::sm2_encrypt(pk, data)
     }
@@ -32,6 +24,11 @@ impl LessCodeEncryption {
     fn sm2_decrypt(sk: String, data: String) -> String {
         SMX::sm2_decrypt(sk, data)
     }
+
+    #[staticmethod]
+    fn sm3_hex(data: String) -> String {
+        SMX::sm3_hex(data)
+    }
     #[staticmethod]
     fn sm4_encrypt(mode: String, data: String, key: String, iv: String) -> String {
         SMX::sm4_encrypt(mode, data, key, iv).unwrap()
@@ -45,5 +42,6 @@ impl LessCodeEncryption {
 #[pymodule]
 fn lesscode_encryption(module: &Bound<'_, PyModule>) -> PyResult<()> {
     module.add_class::<LessCodeEncryption>()?;
+    module.add_class::<Key>()?;
     Ok(())
 }
